@@ -1,15 +1,14 @@
 package Business::ID::NPWP;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2019-11-21'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use warnings;
 use strict;
 
-require Exporter;
-our @ISA = qw(Exporter);
-our @EXPORT = qw(parse_npwp);
+use Exporter 'import';
+our @EXPORT_OK = qw(parse_npwp);
 
 our %SPEC;
 
@@ -82,7 +81,7 @@ Business::ID::NPWP - Parse Indonesian taxpayer registration number (NPWP)
 
 =head1 VERSION
 
-This document describes version 0.07 of Business::ID::NPWP (from Perl distribution Business-ID-NPWP), released on 2015-09-03.
+This document describes version 0.08 of Business::ID::NPWP (from Perl distribution Business-ID-NPWP), released on 2019-11-21.
 
 =head1 SYNOPSIS
 
@@ -124,10 +123,16 @@ each branch.
 =head1 FUNCTIONS
 
 
-=head2 parse_npwp(%args) -> [status, msg, result, meta]
+=head2 parse_npwp
+
+Usage:
+
+ parse_npwp(%args) -> [status, msg, payload, meta]
 
 Parse Indonesian taxpayer registration number (NPWP).
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -143,7 +148,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -171,7 +176,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2015, 2014, 2013 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
